@@ -21,7 +21,7 @@
  */
 
 /*
-   Copyright (C) 1997-2018 by Erik Nolf
+   Copyright (C) 1997-2019 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -102,6 +102,7 @@ int MdcCheckECAT7(FILEINFO *fi)
 void MdcEcatPrintMainHdr(Mdc_Main_header7 *mh)
 {
   int i;
+  time_t my_time;
 
   MdcPrintLine('-',MDC_HALF_LENGTH);
   MdcPrntScrn("ECAT7 Main Header (%d bytes)\n",MH_72_SIZE);
@@ -120,8 +121,8 @@ void MdcEcatPrintMainHdr(Mdc_Main_header7 *mh)
     MdcPrntScrn("(= Unknown)\n");
   MdcGetSafeString(mdcbufr,mh->serial_number,10,10);
   MdcPrntScrn("serial_number            : %s\n",mdcbufr);
-  MdcPrntScrn("scan_start_time          : %s\n"
-                                       ,ctime((time_t *)&mh->scan_start_time));
+  my_time = (time_t)mh->scan_start_time;
+  MdcPrntScrn("scan_start_time          : %s\n",ctime(&my_time));
   MdcGetSafeString(mdcbufr,mh->isotope_name,8,8);
   MdcPrntScrn("isotope_name             : %s\n",mdcbufr);
   MdcPrntScrn("isotope_halflife         : %f [sec]\n",mh->isotope_halflife);
@@ -158,8 +159,8 @@ void MdcEcatPrintMainHdr(Mdc_Main_header7 *mh)
   MdcPrntScrn("patient_age              : %f\n",mh->patient_age);
   MdcPrntScrn("patient_height           : %f\n",mh->patient_height);
   MdcPrntScrn("patient_weight           : %f\n",mh->patient_weight);
-  MdcPrntScrn("patient_birth_date       : %s\n"
-                                    ,ctime((time_t *)&mh->patient_birth_date));
+  my_time = (time_t)mh->patient_birth_date;
+  MdcPrntScrn("patient_birth_date       : %s\n",ctime(&my_time));
   MdcGetSafeString(mdcbufr,mh->physician_name,32,32);
   MdcPrntScrn("physician_name           : %s\n",mdcbufr);
   MdcGetSafeString(mdcbufr,mh->operator_name,32,32);
@@ -186,8 +187,8 @@ void MdcEcatPrintMainHdr(Mdc_Main_header7 *mh)
   MdcPrntScrn("acquisition_mode         : %hd\n",mh->acquisition_mode);
   MdcPrntScrn("bin_size                 : %f [cm]\n",mh->bin_size);
   MdcPrntScrn("branching_fraction       : %f\n",mh->branching_fraction);
-  MdcPrntScrn("dose_start_time          : %s\n"
-                                       ,ctime((time_t *)&mh->dose_start_time));
+  my_time = (time_t)mh->dose_start_time;
+  MdcPrntScrn("dose_start_time          : %s\n",ctime(&my_time));
   MdcPrntScrn("dosage                   : %e [mCi]\n",mh->dosage);
   MdcPrntScrn("well_counter_corr_factor : %f\n",mh->well_counter_corr_factor);
   MdcGetSafeString(mdcbufr,mh->data_units,32,32);
@@ -380,6 +381,7 @@ const char *MdcReadECAT7(FILEINFO *fi)
   const char *err;
   char *str;
   struct tm time, *ptime;
+  time_t my_epoch;
   Mdc_Main_header7 mh;
   Mdc_Image_subheader7 ish;
   Mdc_Attn_subheader7  ash;
@@ -496,10 +498,11 @@ const char *MdcReadECAT7(FILEINFO *fi)
   fi->patient_weight = mh.patient_weight;
 
   ptime = &time;
+  my_epoch = (time_t)mh.patient_birth_date;
 #ifdef HAVE_LOCALTIME_R
-  localtime_r((time_t *)&(mh.patient_birth_date), ptime);
+  localtime_r(&my_epoch, ptime);
 #else
-  ptime = localtime((time_t *)&(mh.patient_birth_date));
+  ptime = localtime(&my_epoch);
 #endif
   if (ptime == NULL) {
     MdcPrntWarn("ECAT7: Couldn't resolve patient birth date");
@@ -512,9 +515,10 @@ const char *MdcReadECAT7(FILEINFO *fi)
 
   ptime = &time;
 #ifdef HAVE_LOCALTIME_R
-  localtime_r((time_t *)&(mh.scan_start_time), ptime);
+  my_epoch = (time_t)(mh.scan_start_time);
+  localtime_r(&my_epoch, ptime);
 #else
-  ptime = localtime((time_t *)&(mh.scan_start_time));
+  ptime = localtime(&my_epoch);
 #endif
   if (ptime == NULL) {
     MdcPrntWarn("ECAT7: Couldn't resolve scan start time");
