@@ -18,7 +18,7 @@
  */
 
 /*
-   Copyright (C) 1997-2018 by Erik Nolf
+   Copyright (C) 1997-2019 by Erik Nolf
 
    This program is free software; you can redistribute it and/or modify it
    under the terms of the GNU General Public License as published by the
@@ -76,7 +76,7 @@ void MdcPrntScrn(char *fmt, ...)
   va_list args;
 
   va_start(args, fmt);
-  vfprintf(MdcPrntStream(), fmt, args);
+  vfprintf(MdcPrntStream(), fmt, args); fflush(MdcPrntStream());
   va_end(args);
 
 }
